<div align="center"><img src="foreign-legion.webp" alt="Foreign legion soldier"></div>
<div align="center"><small><sup>Lapeyre, Lucien, "Tirailleur du 1er Etranger, Létif, 1857" (1906). Prints, Drawings and Watercolors from the Anne S.K. Brown Military Collection. Brown Digital Repository. Brown University Library. https://repository.library.brown.edu/studio/item/bdr:225156/</sup></small></div>
<h1 align="center">
  Galoup
</h1>

<h4 align="center">a Python framework for rolling your own project management tool.</a></h4>

<p align="center">
  <a href="#status">Status</a> •
  <a href="#key-objectives">Key Objectives</a> •
  <a href="#system-requirements">System Requirements</a> •
  <a href="#basic-usage">Example Usage</a> •
  <a href="#contributing">Contributing</a> •
  <a href="#license">License</a>
</p>

<!-- <p align="center">
  <a href="https://travis-ci.com/liampulles/cabiria">
    <img src="https://travis-ci.com/liampulles/cabiria.svg?branch=master" alt="[Build Status]">
  </a>
    <img alt="GitHub go.mod Go version" src="https://img.shields.io/github/go-mod/go-version/liampulles/cabiria">
  <a href="https://goreportcard.com/report/github.com/liampulles/cabiria">
    <img src="https://goreportcard.com/badge/github.com/liampulles/cabiria" alt="[Go Report Card]">
  </a>
  <a href="https://codecov.io/gh/liampulles/cabiria">
    <img src="https://codecov.io/gh/liampulles/cabiria/branch/master/graph/badge.svg" />
  </a>
</p> -->

## Status

Galoup is currently in heavy development.

## Key Objectives

* Provide simple abstractions for creating CLI commands
* Code generation tools
* Git interface
* Pretty logging colors

## System Requirements

* Python 3.6+

## Example Usage

See this repo: <https://github.com/liampulles/rickscafe>

## Contributing

If you wish to make a code change, then I suggest making an issue for your proposal.

## License

See [LICENSE](LICENSE)
